@@ -14,7 +14,7 @@ from ..common import logger, config
 from ..manager import task_status_manager
 from ..control import ProcessTaskManager
 from ..handling import ThreadTerminator, StopException, ThreadSuspender
-from .utils import exit_cleanup_asyncio, shared_task_info
+from .utils import exit_cleanup_asyncio, shared_status_info
 
 _threadsuspender = ThreadSuspender()
 _threadterminator = ThreadTerminator()
@@ -48,10 +48,10 @@ async def _execute_task_async(task: Tuple[bool, str, str, Callable, Tuple, Dict]
             logger.debug(f"Start running task, task ID: {task_id}")
 
             if timeout_processing:
-                return_results = await asyncio.wait_for(func(*args, **kwargs),
+                return_results = await asyncio.wait_for(func(task_id, *args, **kwargs),
                                                         timeout=config["watch_dog_time"])
             else:
-                return_results = await func(*args, **kwargs)
+                return_results = await func(task_id, *args, **kwargs)
 
     return return_results
 
@@ -105,7 +105,6 @@ def _execute_task(task: Tuple[bool, str, str, Callable, Tuple, Dict],
         # Remove main thread logging
         if task_manager.check(task_id):
             task_manager.remove(task_id)
-
     return result
 
 
@@ -152,10 +151,10 @@ class CpuAsyncioTask:
         """
         Handle task status updates from the task status queue.
         """
-        while not self._scheduler_stop_event.is_set() or not shared_task_info.task_status_queue.empty():
+        while not self._scheduler_stop_event.is_set() or not shared_status_info.task_status_queue.empty():
             try:
-                if not shared_task_info.task_status_queue.empty():
-                    task = shared_task_info.task_status_queue.get(timeout=0.1)
+                if not shared_status_info.task_status_queue.empty():
+                    task = shared_status_info.task_status_queue.get(timeout=0.1)
                     status, task_id, task_name, start_time, end_time, error, timeout_processing = task
                     task_status_manager.add_task_status(task_id, task_name, status, start_time, end_time, error,
                                                         timeout_processing, "cpu_asyncio_task")
@@ -190,7 +189,7 @@ class CpuAsyncioTask:
         """
         try:
             with self._scheduler_lock:
-                shared_task_info.task_status_queue.put(("queuing", task_id, None, None, None, None, None))
+                shared_status_info.task_status_queue.put(("queuing", task_id, None, None, None, None, None))
                 if self._task_queue.qsize() >= config["cpu_asyncio_task"]:
                     return False
 
@@ -201,7 +200,7 @@ class CpuAsyncioTask:
                     self._join_scheduler_thread()
 
                 # Reduce the granularity of the lock
-                shared_task_info.task_status_queue.put(("waiting", task_id, None, None, None, None, None))
+                shared_status_info.task_status_queue.put(("waiting", task_id, None, None, None, None, None))
 
                 self._task_queue.put((timeout_processing, task_name, task_id, func, args, kwargs))
 
@@ -281,9 +280,9 @@ class CpuAsyncioTask:
 
     def stop_all_running_task(self):
         for task_id in self._running_tasks.keys():
-            shared_task_info.task_signal_transmission[task_id] = ["kill"]
+            shared_status_info.task_signal_transmission[task_id] = ["kill"]
 
-        while not len(shared_task_info.task_signal_transmission.items()) == 0:
+        while not len(shared_status_info.task_signal_transmission.items()) == 0:
             try:
                 time.sleep(0.1)
             except KeyboardInterrupt:
@@ -311,8 +310,8 @@ class CpuAsyncioTask:
 
                 timeout_processing, task_name, task_id, func, args, kwargs = task
                 with self._lock:
-                    future = executor.submit(_execute_task, task, shared_task_info.task_status_queue,
-                                             shared_task_info.task_signal_transmission)
+                    future = executor.submit(_execute_task, task, shared_status_info.task_status_queue,
+                                             shared_status_info.task_signal_transmission)
                     self._running_tasks[task_id] = [future, task_name, ]
 
                     future.add_done_callback(partial(self._task_done, task_id))
@@ -334,7 +333,7 @@ class CpuAsyncioTask:
         except (KeyboardInterrupt, BrokenExecutor):
             # Prevent problems caused by exit errors
             logger.warning(f"task | {task_id} | cancelled, forced termination")
-            shared_task_info.task_status_queue.put(("cancelled", task_id, None, None, None, None, None))
+            shared_status_info.task_status_queue.put(("cancelled", task_id, None, None, None, None, None))
             result = "cancelled action"
 
         except Exception as e:
@@ -343,13 +342,13 @@ class CpuAsyncioTask:
 
             # if not "Cannot close a running event loop" in str(e):
             logger.error(f"task | {task_id} | execution failed: {e}")
-            shared_task_info.task_status_queue.put(("failed", task_id, None, None, None, e, None))
+            shared_status_info.task_status_queue.put(("failed", task_id, None, None, None, e, None))
             result = "failed action"
 
         finally:
             # The results returned by the storage task can be retained for a maximum of two results
             if result not in ["timeout action", "cancelled action", "failed action"]:
-                shared_task_info.task_status_queue.put(("completed", task_id, None, None, None, None, None))
+                shared_status_info.task_status_queue.put(("completed", task_id, None, None, None, None, None))
                 if result is not None:
                     with self._lock:
                         self._task_results[task_id] = [result, time.time()]
@@ -422,9 +421,9 @@ class CpuAsyncioTask:
             future.cancel()
         else:
             # First ensure that the task is not paused.
-            shared_task_info.task_signal_transmission[task_id] = ["resume", "kill"]
+            shared_status_info.task_signal_transmission[task_id] = ["resume", "kill"]
 
-        shared_task_info.task_status_queue.put(("cancelled", task_id, None, None, None, None, None))
+        shared_status_info.task_status_queue.put(("cancelled", task_id, None, None, None, None, None))
         return True
 
     def pause_task(self,
@@ -442,8 +441,8 @@ class CpuAsyncioTask:
             logger.warning(f"task | {task_id} | does not exist or is already completed")
             return False
 
-        shared_task_info.task_signal_transmission[task_id] = ["pause"]
-        shared_task_info.task_status_queue.put(("paused", task_id, None, None, None, None, None))
+        shared_status_info.task_signal_transmission[task_id] = ["pause"]
+        shared_status_info.task_status_queue.put(("paused", task_id, None, None, None, None, None))
 
         return True
 
@@ -462,8 +461,8 @@ class CpuAsyncioTask:
             logger.warning(f"task | {task_id} | does not exist or is already completed")
             return False
 
-        shared_task_info.task_signal_transmission[task_id] = ["resume"]
-        shared_task_info.task_status_queue.put(("running", task_id, None, None, None, None, None))
+        shared_status_info.task_signal_transmission[task_id] = ["resume"]
+        shared_status_info.task_status_queue.put(("running", task_id, None, None, None, None, None))
 
         return True
 
