@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 # Author: fallingmeteorite
 from .end_cleaning import exit_cleanup_liner, exit_cleanup_asyncio
-from .info_share import shared_task_info
+from .info_share import shared_status_info
 from .priority_check import TaskCounter
 from .parameter_check import get_param_count
 
-__all__ = ['exit_cleanup_liner', 'exit_cleanup_asyncio', 'shared_task_info', 'TaskCounter', 'get_param_count']
+__all__ = ['exit_cleanup_liner', 'exit_cleanup_asyncio', 'shared_status_info', 'TaskCounter', 'get_param_count']
