@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 # Author: fallingmeteorite
-import os
 import signal
 import sys
 import threading
@@ -11,7 +10,7 @@ def exit_cleanup_liner() -> None:
     Used to fix the error that occurs when ending a task after the process is recycled.
     """
 
-    def signal_handler(signum, frame):
+    def signal_handler(signum, frame) -> None:
         """
         Signal handler for graceful process termination.
 
@@ -32,7 +31,7 @@ def exit_cleanup_asyncio() -> None:
     Used to fix the error that occurs when ending a task after the process is recycled.
     """
 
-    def signal_handler(signum, frame):
+    def signal_handler(signum, frame) -> None:
         """
         Signal handler for graceful process termination.
 
