@@ -3,5 +3,6 @@
 from .sleep import interruptible_sleep
 from .random import random_name
 from .decorator import wait_branch_thread_ended, branch_thread_control
+from .retry import retry_on_error
 
-__all__ = ['interruptible_sleep', 'random_name', 'wait_branch_thread_ended', 'branch_thread_control']
+__all__ = ['interruptible_sleep', 'random_name', 'wait_branch_thread_ended', 'branch_thread_control', 'retry_on_error']
